@@ -1,17 +1,16 @@
  
 c interface to Lapack's zggev and zhegv
-c input character arguments with length 255 converted to character*1.
  
-      subroutine xzggev(kjobvl, kjobvr, n, a, lda, b, ldb, alpha, beta,
+      subroutine xzggev(kjobvl, kjobvr, n, a, b, alpha, beta,
      *                  vl, ldvl, vr, ldvr, work, lwork, rwork, info )
 c
 c     .. Scalar Arguments ..
       integer            kjobvl, kjobvr
-      integer            info, lda, ldb, ldvl, ldvr, lwork, n
+      integer            info, ldvl, ldvr, lwork, n
 c     ..
 c     .. Array Arguments ..
       double precision   rwork(*) 
-      complex*16         a(lda, *) , alpha(*), b(ldb, *),
+      complex*16         a(n, *) , alpha(*), b(n, *),
      *                   beta(*), vl(ldvl, *), vr(ldvr, *),
      *                   work(*)
 
@@ -20,29 +19,29 @@ c     .. Array Arguments ..
       jobvl = 'NV'(kjobvl:kjobvl)
       jobvr = 'NV'(kjobvr:kjobvr)
 
-      call zggev(jobvl, jobvr, n, a, lda, b, ldb, alpha, beta,
+      call zggev(jobvl, jobvr, n, a, n, b, n, alpha, beta,
      *           vl, ldvl, vr, ldvr, work, lwork, rwork, info )
      
       return
       end
       
-      subroutine xzhegv(itype, kjobz, kuplo, n, a, lda, b, ldb, w, work,
+      subroutine xzhegv(itype, kjobz, kuplo, n, a, b, w, work,
      *                  lwork, rwork, info )
 
 c     .. Scalar Arguments ..
       integer            kjobz, kuplo
-      integer            info, itype, lda, ldb, lwork, n
+      integer            info, itype, lwork, n
 c     ..
 c     .. Array Arguments ..
       double precision   rwork(*), w(*)
-      complex*16         a(lda, *), b(ldb, *), work(*)
+      complex*16         a(n, *), b(n, *), work(*)
       
       character          jobz, uplo
 
       jobz = 'NV'(kjobz:kjobz)
       uplo = 'UL'(kuplo:kuplo)
 
-      call zhegv(itype, jobz, uplo, n, a, lda, b, ldb, w, work,
+      call zhegv(itype, jobz, uplo, n, a, n, b, n, w, work,
      *           lwork, rwork, info )
 
       return
